@@ -1,4 +1,6 @@
+from django.contrib.contenttypes.models import ContentType
 from django.http import Http404
+from django.shortcuts import get_object_or_404
 
 from cms.carousels.forms import CarouselForm
 from cms.carousels.models import *
@@ -6,11 +8,11 @@ from cms.carousels.serializers import *
 
 from rest_framework.permissions import IsAdminUser
 from rest_framework.response import Response
+from rest_framework.schemas.openapi import AutoSchema
 from rest_framework.views import APIView
 
 from . generics import *
-from . locks import ObjectUserLocksList, ObjectUserLocksView
-
+from . logs import ObjectLogEntriesList
 from .. exceptions import LoggedPermissionDenied
 from .. permissions import CarouselGetCreatePermissions
 from .. serializers import UniCMSFormSerializer
@@ -78,3 +80,21 @@ class CarouselFormView(APIView):
         form = CarouselForm()
         form_fields = UniCMSFormSerializer.serialize(form)
         return Response(form_fields)
+
+
+class CarouselLogsSchema(AutoSchema):
+    def get_operation_id(self, path, method):# pragma: no cover
+        return 'listCarouselLogs'
+
+
+class CarouselLogsView(ObjectLogEntriesList):
+
+    schema = CarouselLogsSchema()
+
+    def get_queryset(self, **kwargs):
+        """
+        """
+        object_id = self.kwargs['pk']
+        item = get_object_or_404(Carousel, pk=object_id)
+        content_type_id = ContentType.objects.get_for_model(item).pk
+        return super().get_queryset(object_id, content_type_id)
