@@ -1,4 +1,6 @@
+from django.contrib.contenttypes.models import ContentType
 from django.http import Http404
+from django.shortcuts import get_object_or_404
 
 from cms.carousels.forms import CarouselItemLinkForm
 from cms.carousels.models import *
@@ -6,9 +8,11 @@ from cms.carousels.serializers import *
 
 from rest_framework.permissions import IsAdminUser
 from rest_framework.response import Response
+from rest_framework.schemas.openapi import AutoSchema
 from rest_framework.views import APIView
 
 from . generics import *
+from . logs import ObjectLogEntriesList
 from .. exceptions import LoggedPermissionDenied
 from .. serializers import UniCMSFormSerializer
 from .. utils import check_user_permission_on_object
@@ -27,8 +31,10 @@ class CarouselItemLinkList(UniCMSListCreateAPIView):
         carousel_id = self.kwargs.get('carousel_id')
         carousel_item_id = self.kwargs.get('carousel_item_id')
         if carousel_id and carousel_item_id:
-            return CarouselItemLink.objects.filter(carousel_item__carousel__pk=carousel_id,
-                                                   carousel_item__pk=carousel_item_id)
+            return CarouselItemLink.objects\
+                                   .select_related('carousel_item')\
+                                   .filter(carousel_item__carousel__pk=carousel_id,
+                                           carousel_item__pk=carousel_item_id)
         return CarouselItemLink.objects.none() # pragma: no cover
 
     def post(self, request, *args, **kwargs):
@@ -109,3 +115,26 @@ class CarouselItemLinksFormView(APIView):
                                     carousel_id=kwargs.get('carousel_id'))
         form_fields = UniCMSFormSerializer.serialize(form)
         return Response(form_fields)
+
+
+class CarouselItemLinkLogsSchema(AutoSchema):
+    def get_operation_id(self, path, method):# pragma: no cover
+        return 'listCarouselItemLinkLogs'
+
+
+class CarouselItemLinkLogsView(ObjectLogEntriesList):
+
+    schema = CarouselItemLinkLogsSchema()
+
+    def get_queryset(self, **kwargs):
+        """
+        """
+        carousel_id = self.kwargs['carousel_id']
+        carousel_item_id = self.kwargs['carousel_item_id']
+        object_id = self.kwargs['pk']
+        item = get_object_or_404(CarouselItemLink.objects.select_related('carousel_item'),
+                                 pk=object_id,
+                                 carousel_item__carousel__pk=carousel_id,
+                                 carousel_item__pk=carousel_item_id)
+        content_type_id = ContentType.objects.get_for_model(item).pk
+        return super().get_queryset(object_id, content_type_id)
